@@ -8,20 +8,13 @@ from .utils import make_str, make_default_short_help, echo
 from .exceptions import ClickException, UsageError, Abort
 from .termui import prompt, confirm
 from .formatting import HelpFormatter
-from .parser import OptionParser
+from .parser import OptionParser, split_opt
 
 from ._compat import PY2, isidentifier
 
 _missing = object()
 
 
-def _cleanup_name(name):
-    prefix = name[:1]
-    if not prefix.isalnum():
-        return name.lstrip(prefix)
-    return name
-
-
 class Context(object):
     """The context is a special internal object that holds state relevant
     for the script execution at every single level.  It's normally invisible
@@ -713,9 +706,8 @@ class Parameter(object):
         if self.metavar is not None:
             return self.metavar
         metavar = self.type.get_metavar(self)
-        if metavar is not None:
-            return metavar
-        metavar = self.name.upper()
+        if metavar is None:
+            metavar = self.type.name.upper()
         if self.nargs != 1:
             metavar += '...'
         return metavar
@@ -750,13 +742,20 @@ class Parameter(object):
             return tuple(_convert(x, level - 1) for x in value or ())
         return _convert(value, (self.nargs != 1) + bool(self.multiple))
 
+    def value_is_missing(self, value):
+        if value is None:
+            return True
+        if (self.nargs != 1 or self.multiple) and value == ():
+            return True
+        return False
+
     def full_process_value(self, ctx, value):
         value = self.process_value(ctx, value)
 
         if value is None:
             value = self.get_default(ctx)
 
-        if value is None and self.required:
+        if self.required and self.value_is_missing(value):
             ctx.fail(self.get_missing_message(ctx))
 
         return value
@@ -802,7 +801,7 @@ class Option(Parameter):
     All other parameters are passed onwards to the parameter constructor.
 
     :param show_default: controls if the default value should be shown on the
-                         help page.  The default is auto detection.
+                         help page.  Normally defaults are not shown.
     :param prompt: if set to `True` or a non empty string then the user will
                    be prompted for input if not set.  If set to `True` the
                    prompt will be the option name capitalized.
@@ -829,7 +828,7 @@ class Option(Parameter):
     """
     param_type_name = 'option'
 
-    def __init__(self, param_decls=None, show_default=None,
+    def __init__(self, param_decls=None, show_default=False,
                  prompt=False, confirmation_prompt=False,
                  hide_input=False, is_flag=None, flag_value=None,
                  multiple=False, count=False, allow_from_autoenv=True,
@@ -854,13 +853,10 @@ class Option(Parameter):
 
         if is_flag and default_is_missing:
             self.default = False
-            if show_default is None:
-                show_default = False
 
         if flag_value is None:
             flag_value = not self.default
 
-        self.show_default = show_default
         self.is_flag = is_flag
         self.flag_value = flag_value
         self.multiple = multiple
@@ -878,6 +874,7 @@ class Option(Parameter):
 
         self.allow_from_autoenv = allow_from_autoenv
         self.help = help
+        self.show_default = show_default
 
         # Sanity check for stuff we don't support
         if __debug__:
@@ -911,16 +908,16 @@ class Option(Parameter):
             else:
                 if '/' in decl:
                     first, second = decl.split('/', 1)
-                    possible_names.append(_cleanup_name(first))
+                    possible_names.append(split_opt(first))
                     opts.append(first)
                     secondary_opts.append(second)
                 else:
-                    possible_names.append(_cleanup_name(decl))
+                    possible_names.append(split_opt(decl))
                     opts.append(decl)
 
         if name is None and possible_names:
-            possible_names.sort(key=len)
-            name = possible_names[-1].replace('-', '_')
+            possible_names.sort(key=lambda x: len(x[0]))
+            name = possible_names[-1][1].replace('-', '_')
             if not isidentifier(name):
                 name = None
 
@@ -962,10 +959,16 @@ class Option(Parameter):
         def _write_opts(opts):
             rv = []
             for opt in opts:
-                if not self.is_flag:
-                    opt += ' ' + self.make_metavar()
-                rv.append(opt)
-            return ', '.join(rv)
+                prefix = split_opt(opt)[0]
+                rv.append((len(prefix), opt))
+
+            rv.sort(key=lambda x: x[0])
+
+            rv = ', '.join(x[1] for x in rv)
+            if not self.is_flag:
+                rv += ' ' + self.make_metavar()
+            return rv
+
         rv = [_write_opts(self.opts)]
         if self.secondary_opts:
             rv.append(_write_opts(self.secondary_opts))
@@ -976,8 +979,6 @@ class Option(Parameter):
             extra.append('default: %s' % self.default)
         if self.required:
             extra.append('required')
-        if self.nargs != 1:
-            extra.append('%d arguments' % self.nargs)
         if extra:
             help = '%s[%s]' % (help and help + '  ' or '', '; '.join(extra))
 
